📦
1358 /agent.js.map
983 /agent.js
✄
{"version":3,"file":"agent.js","names":["NSURL","NSString","NSNumber","NSDictionary","LSApplicationWorkspace","ObjC","classes","Agent","constructor","this","available","checkDependents","Process","findModuleByName","Module","load","uiopen","url","code","message","module","getModuleByName","options","optionKey","getExportByName","value","numberWithBool_","dictionaryWithObject_forKey_","readPointer","objcURL","URLWithString_","defaultWorkspace","openSensitiveURL_withOptions_","e","agent","rpc","exports","bind"],"sourceRoot":"/Users/cu/Documents/Reverse/Tools/frida-uiopen/agent/","sources":["agent.ts"],"mappings":"AAAA,MAAMA,MACFA,EAAKC,SACLA,EAAQC,SACRA,EAAQC,aACRA,EAAYC,uBACZA,GACAC,KAAKC,QAKT,MAAMC,EAUF,WAAAC,GACIC,KAAKC,UAAYH,EAAMI,iBAC3B,CAVA,sBAAOA,GACH,SAAKC,QAAQC,iBAAiB,wBACrBC,OAAOC,KAAK,0FAIXX,GAA2BH,GAAaD,GAAUE,GAAaC,EAC7E,CAIA,MAAAa,CAAOC,GACH,IAAKR,KAAKC,UACN,MAAO,CAACQ,MAAO,EAAGC,QAAS,wCAE/B,IACI,MAAMC,EAASR,QAAQS,gBAAgB,sBACvC,IAAIC,EAA8B,KAClC,MAAMC,EAAYH,EAAOI,gBAAgB,2CACzC,GAAID,EAAW,CACX,MAAME,EAAQvB,EAASwB,iBAAgB,GACvCJ,EAAWnB,EAAawB,6BAA6BF,EAAOF,EAAUK,c,CAE1E,MAAMC,EAAU7B,EAAM8B,eAAeb,GACrC,OAAKb,EAAuB2B,mBAAmBC,8BAA8BH,EAASP,GAG/E,CAACJ,KAAM,EAAGC,QAAS,YAFd,CAACD,MAAO,EAAGC,QAAS,+B,CAGlC,MAAOc,GACL,MAAO,CAACf,MAAO,EAAGC,QAAS,2DAA2Dc,I,CAE9F,EAGJ,MAAMC,EAAQ,IAAI3B,EAClB4B,IAAIC,QAAU,CACVpB,OAAUkB,EAAMlB,OAAOqB,KAAKH"}
✄
const{NSURL:e,NSString:o,NSNumber:t,NSDictionary:r,LSApplicationWorkspace:n}=ObjC.classes;class c{constructor(){this.available=c.checkDependents()}static checkDependents(){return!(!Process.findModuleByName("FrontBoardServices")&&!Module.load("/System/Library/PrivateFrameworks/FrontBoardServices.framework/FrontBoardServices"))&&!!(n&&o&&e&&t&&r)}uiopen(o){if(!this.available)return{code:-1,message:"Environment dependency check failed."};try{const c=Process.getModuleByName("FrontBoardServices");let i=null;const s=c.getExportByName("FBSOpenApplicationOptionKeyUnlockDevice");if(s){const e=t.numberWithBool_(!0);i=r.dictionaryWithObject_forKey_(e,s.readPointer())}const a=e.URLWithString_(o);return n.defaultWorkspace().openSensitiveURL_withOptions_(a,i)?{code:0,message:"Success."}:{code:-2,message:"Failed to execute URL event."}}catch(e){return{code:-3,message:`An exception occurred when the operation was performed: ${e}`}}}}const i=new c;rpc.exports={uiopen:i.uiopen.bind(i)};